@@ -328,17 +328,6 @@ rstyle_apply (GnmStyle **old, ReplacementStyle *rs, GnmRange const *r)
 	}
 }
 
-void
-sheet_style_clear_style_dependents (Sheet *sheet, GnmRange const *r)
-{
-	GSList *styles = sh_all_styles (sheet->style_data->style_hash);
-	g_slist_foreach (styles,
-			 (GFunc)gnm_style_unlink_dependents,
-			 (gpointer)r);
-	g_slist_free (styles);
-}
-
-
 /****************************************************************************/
 
 typedef enum {
@@ -867,11 +856,11 @@ sheet_style_get_auto_pattern_color (Sheet const *sheet)
  * is used for the grid.
  */
 void
-sheet_style_update_grid_color (Sheet const *sheet)
+sheet_style_update_grid_color (Sheet const *sheet, GtkStyleContext *context)
 {
 	GnmColor *default_auto = style_color_auto_pattern ();
 	GnmColor *sheet_auto = sheet_style_get_auto_pattern_color (sheet);
-	GnmColor *grid_color = style_color_grid ();
+	GnmColor *grid_color = style_color_grid (context);
 	GnmColor *new_color;
 
 	new_color = (style_color_equal (default_auto, sheet_auto)
@@ -1381,7 +1370,7 @@ sheet_style_set_pos (Sheet *sheet, int col, int row,
  * sheet_style_default:
  * @sheet:
  *
- * Returns a reference to default style for a sheet.
+ * Returns: (transfer full): default style for the sheet.
  **/
 GnmStyle *
 sheet_style_default (Sheet const *sheet)
